Learn R Programming

canadamaps (version 0.1)

get_agricultural_divisions: Canadian Map at Census Agricultural Region (CAR) Level

Description

This function aggregates the Census Divisions (CD) map to provide the Census Agricultural Region (CAR) map. The idea is to avoid providing a dataset with map that can be obtained as an aggregation of another.

Usage

get_agricultural_divisions(map = census_divisions)

Arguments

map

which map to add, by default it takes the complete Census Divisions (CD) map

Value

a tibble with economic regions, provinces and geometry (multipolygon) fields.

Examples

Run this code
# NOT RUN {
get_agricultural_divisions(
 census_divisions[census_divisions$prname == "Ontario",]
)
# }

Run the code above in your browser using DataLab