Learn R Programming

canadamaps (version 0.1)

get_economic_regions: Canadian Map at Economic Region (ER) Level

Description

This function aggregates the Census Divisions (CD) map to provide the Economic Region (ER) map. The idea is to avoid providing a dataset with map that can be obtained as an aggregation of another.

Usage

get_economic_regions(map = census_divisions)

Arguments

map

which map to add, by default it takes the complete Census Divisions (CD) map

Value

a tibble with economic regions, provinces and geometry (multipolygon) fields.

Examples

Run this code
# NOT RUN {
get_economic_regions(
 census_divisions[census_divisions$prname == "Ontario",]
)
# }

Run the code above in your browser using DataLab